@@ -48,7 +48,7 @@ def clean_dataframe(df):
     dropped_rows = []
     for idx in df.index:
         local_time_str = df["Local_Time"][idx]
-        if (local_time_str == "-1") or len(local_time_str.split(' ')) > 3:
+        if (local_time_str == "-1") or len(local_time_str.split(' ')) > 3 or ("20212021" in local_time_str):
             dropped_rows.append(idx)
     df = df.drop(dropped_rows)
 
