@@ -49,6 +49,7 @@ def extract_reprompt(df_pr_phone):
             new_reprompt_row.append(row["Answer_Status"])
             new_reprompt_row.append(row["Initial_Prompt_Local_Time"])
             new_reprompt_row.append(row["Initial_Prompt_UTC_Offset "])
+            new_reprompt_row.append("0")
             prompt_arrays.append(new_reprompt_row)
 
             # reprompt
@@ -65,6 +66,7 @@ def extract_reprompt(df_pr_phone):
                     new_reprompt_row.append(row["Answer_Status"])
                     new_reprompt_row.append(row[reprompt_local])
                     new_reprompt_row.append(row["Initial_Prompt_UTC_Offset "])
+                    new_reprompt_row.append(str(i))
                     prompt_arrays.append(new_reprompt_row)
 
         else:
@@ -84,6 +86,7 @@ def extract_reprompt(df_pr_phone):
                 new_reprompt_row.append(row["Answer_Status"])
                 new_reprompt_row.append(row["Initial_Prompt_Local_Time"])
                 new_reprompt_row.append(row["Initial_Prompt_UTC_Offset "])
+                new_reprompt_row.append("0")
                 prompt_arrays.append(new_reprompt_row)
                 continue
             else:
@@ -97,6 +100,7 @@ def extract_reprompt(df_pr_phone):
                         new_reprompt_row.append(status)
                         new_reprompt_row.append(row["Initial_Prompt_Local_Time"])
                         new_reprompt_row.append(row["Initial_Prompt_UTC_Offset "])
+                        new_reprompt_row.append("0")
                         prompt_arrays.append(new_reprompt_row)
 
                     else:
@@ -115,11 +119,12 @@ def extract_reprompt(df_pr_phone):
                         new_reprompt_row.append(status)
                         new_reprompt_row.append(row[reprompt_local])
                         new_reprompt_row.append(row["Initial_Prompt_UTC_Offset "])
+                        new_reprompt_row.append(str(i))
                         prompt_arrays.append(new_reprompt_row)
 
     df_prompt = pd.DataFrame(prompt_arrays)
     if df_prompt.shape[0] > 0:
-        df_prompt.columns = ['Prompt_Type', 'Study_Mode', 'Initial_Prompt_Local_Time', 'Answer_Status', 'Question_Set_Prompt_Local_Time', 'UTC_Offset']
+        df_prompt.columns = ['Prompt_Type', 'Study_Mode', 'Initial_Prompt_Local_Time', 'Answer_Status', 'Question_Set_Prompt_Local_Time', 'UTC_Offset', "Reprompt_Num"]
 
     return df_prompt
 
