@@ -26,7 +26,7 @@ from microt_compliance_matrix import utils
 from microt_compliance_matrix import feature_engineering_ema
 
 
-def compute_features_phone(intermediate_participant_path, output_dir_path, date_in_study, decryption_password):
+def compute_features_phone(intermediate_participant_path, output_dir_path, date_in_study, lsf_json_folder_path, decryption_password):
     # Switch
     print_stats = False
 
@@ -78,7 +78,9 @@ def compute_features_phone(intermediate_participant_path, output_dir_path, date_
     feature_df['LOCATION'] = feature7
     feature_df['match_time_location'] = match_time_location
 
-    # - feature 6: Location related
+    # - feature 6: Location label
+    feature8 = feature_engineering_ema.location_label.create_column(lsf_json_folder_path, participant_id, feature7)
+    feature_df['LOCATION_LABEL'] = feature8
 
     # - feature 7: Screen Status
     feature9, match_time_screen = feature_engineering_ema.screen_status.create_column(df_prompt['Prompt_Local_DateTime'], intermediate_participant_path, date_in_study)
